@@ -55,18 +55,10 @@
 #define XI_JOYSTICK "JOYSTICK"
 #endif
 
-#if GET_ABI_MAJOR(ABI_XINPUT_VERSION) < 5
-typedef struct {
-    char *rules;
-    char *model;
-    char *layout;
-    char *variant;
-    char *options;
-} XkbRMLVOSet;
+#ifndef XI86_SERVER_FD
+#define XI86_SERVER_FD 0x20
 #endif
 
-
-
 typedef enum _JOYSTICKEVENT {
     EVENT_NONE=0,
     EVENT_BUTTON,
@@ -117,7 +109,8 @@ typedef struct _JoystickDevRec {
     jstkReadDataProc read_proc; /* Callback for reading data from the backend */
     void         *devicedata; /* Extra platform device dependend data */
     char         *device;     /* Name of the device */
-    LocalDevicePtr keyboard_device; /* Slave device for keyboard events */
+    InputInfoPtr joystick_device; /* Back pointer to the joystick device */
+    InputInfoPtr keyboard_device; /* Slave device for keyboard events */
 
     OsTimerPtr   timer;       /* Timer for axis movement */
     Bool         timerrunning;
@@ -134,4 +127,6 @@ typedef struct _JoystickDevRec {
     BUTTON button[MAXBUTTONS];    /* Configuration per button */
 } JoystickDevRec;
 
+void jstkCloseDevice(JoystickDevPtr priv);
+
 #endif
